## Certainty

Simulated tasks to be learned within environments that are used to evaluate probablistic models of certainty.

### Verisoning

This project uses [Semantic Versioning 2.0.0](https://semver.org/spec/v2.0.0.html).
This project's version will remain < 1.0.0 until adequate unit test coverage exists.

### License

This project's license is the MIT license as seen in LICENSE.txt.
